<?php
/**
 * @subpackage Empo
 */

/**
 * Make theme available for translation
 * Translations can be filed in the /languages/ directory
 */
load_theme_textdomain( 'empo', get_template_directory() . '/languages' );

$locale = get_locale();
$locale_file = get_template_directory() . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );
/*-----------------------------------------------------------------------------------*/
// Scripts
/*-----------------------------------------------------------------------------------*/
function empo_scripts_styles() {
	/*
	 * Adds JavaScript to pages with the comment form to support sites with
	 * threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	// Loads JavaScript file with functionality specific to Empo.
	wp_enqueue_script( 'empo-script', get_template_directory_uri() . '/js/screen.js', array( 'jquery' ), '20130211', true );

	// Loads our main stylesheet.
	wp_enqueue_style( 'empo-style', get_stylesheet_uri() );
	wp_enqueue_style( 'empo-skeleton', get_template_directory_uri() . '/css/skeleton.css', array( 'empo-style' ), '20130213' );
}
add_action( 'wp_enqueue_scripts', 'empo_scripts_styles' );

/*-----------------------------------------------------------------------------------*/
// Header scripts and styles
/*-----------------------------------------------------------------------------------*/
function empo_custom_styles(){
    get_template_part( 'includes/custom', 'styles' );		// Custom styles
}
add_action( 'wp_head', 'empo_custom_styles', 50 );// add to header. 50 is the priority(Lower numbers correspond with earlier execution. Not specified = 10)

/**
 * Set the content width based on the theme's design and stylesheet.
 */	
if ( ! isset( $content_width ) )
	$content_width = 960;
	
/**
 * Creates a nicely formatted and more specific title element text for output
 * in head of document, based on current view.
 */
function empo_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'empo' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'empo_wp_title', 10, 2 );

/**
 * Tell WordPress to run empo() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'empo' );

if ( ! function_exists( 'empo' ) ):

/**
 * Sets up theme defaults and registers support for WordPress features. 
 */
function empo() {

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Navigation', 'empo' ),
	) );
	
	// Add support for Post Formats
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'link', 'video', 'image', 'quote' ) );

	// This theme allows users to set a custom background
	add_theme_support( 'custom-background' ); 

	// Your changeable header business starts here
	define( 'HEADER_TEXTCOLOR', '' );
	// No CSS, just IMG call. The %s is a placeholder for the theme template directory URI.
	define( 'HEADER_IMAGE', '%s/images/headers/urban.jpg' );

	// The height and width of your custom header. You can hook into the theme's own filters to change these values.
	// Add a filter to empo_header_image_width and empo_header_image_height to change these values.
	define( 'HEADER_IMAGE_WIDTH', apply_filters( 'empo_header_image_width', 960 ) );
	define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'empo_header_image_height', 350 ) );

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be 940 pixels wide by 350 pixels tall.
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true );

	// Don't support text inside the header image.
	define( 'NO_HEADER_TEXT', true );

	// Add a way for the custom header to be styled in the admin panel that controls
	// custom headers. See empo_admin_header_style(), below.
	
    add_theme_support( 'custom-header', array('empo_admin_header_style') );
	
	// ... and thus ends the changeable header business.

	// Default custom headers packaged with the theme. %s is a placeholder for the theme template directory URI.
	register_default_headers( array(
			'beach' => array(
			'url' => '%s/images/headers/beach.jpg',
			'thumbnail_url' => '%s/images/headers/beach-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Beach', 'empo' )
			),
			'urban' => array(
			'url' => '%s/images/headers/urban.jpg',
			'thumbnail_url' => '%s/images/headers/urban-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Urban', 'empo' )
			),
			'palms' => array(
			'url' => '%s/images/headers/palms.jpg',
			'thumbnail_url' => '%s/images/headers/palms-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Palms', 'empo' )
			),
			'romantic' => array(
			'url' => '%s/images/headers/romantic.jpg',
			'thumbnail_url' => '%s/images/headers/romantic-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Romantic', 'empo' )
			),
			'summer' => array(
			'url' => '%s/images/headers/summer.jpg',
			'thumbnail_url' => '%s/images/headers/summer-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Summer', 'empo' )
			),
			'landscape' => array(
			'url' => '%s/images/headers/landscape.jpg',
			'thumbnail_url' => '%s/images/headers/landscape-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Landscape', 'empo' )
			)
	) );
}
endif;

if ( ! function_exists( 'empo_admin_header_style' ) ) :

/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 * Referenced via add_custom_image_header() in empo_setup().
 */
function empo_admin_header_style() {
?>
<style type="text/css">
/* Shows the same border as on front end */
#heading {
	border-bottom: 1px solid #000;
	border-top: 4px solid #000;
}
/* If NO_HEADER_TEXT is false, you would style the text with these selectors:
	#headimg #name { }
	#headimg #desc { }
*/
</style>
<?php
}
endif;

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function empo_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'empo_page_menu_args' );

/**
 * Sets the post excerpt length to 40 characters.
 */
function empo_excerpt_length( $length ) {
	return 40;
}
add_filter( 'excerpt_length', 'empo_excerpt_length' );

/**
 * Returns a "Continue Reading" link for excerpts
 */
function empo_continue_reading_link() {
	return ' <a href="'. get_permalink() . '">' . __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'empo' ) . '</a>';
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and empo_continue_reading_link().
 *
 * To override this in a child theme, remove the filter and add your own
 * function tied to the excerpt_more filter hook.
 */
function empo_auto_excerpt_more( $more ) {
	return ' &hellip;' . empo_continue_reading_link();
}
add_filter( 'excerpt_more', 'empo_auto_excerpt_more' );

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * To override this link in a child theme, remove the filter and add your own
 * function tied to the get_the_excerpt filter hook.
 */
function empo_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= empo_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'empo_custom_excerpt_more' );

/**
 * Remove inline styles printed when the gallery shortcode is used.
 */
function empo_remove_gallery_css( $css ) {
	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
}
add_filter( 'gallery_style', 'empo_remove_gallery_css' );

if ( ! function_exists( 'empo_comment' ) ) :

/**
 * Template for comments and pingbacks. 
 */
function empo_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-gravatar"><?php echo get_avatar( $comment, 65 ); ?></div>
		
		<div class="comment-body">
		<div class="comment-meta commentmetadata"> 
		<?php printf( __( '%s', 'empo' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?><br/>
		<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
			<?php
				/* translators: 1: date, 2: time */
				printf( __( '%1$s at %2$s', 'empo' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( 'Edit &rarr;', 'empo' ), ' ' );
			?>		
		</div><!-- .comment-meta .commentmetadata -->

		<?php comment_text(); ?>
		
		<?php if ( $comment->comment_approved == '0' ) : ?>
		<p class="moderation"><?php _e( 'Your comment is awaiting moderation.', 'empo' ); ?></p>
		<?php endif; ?>

		<div class="reply">
			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		</div><!-- .reply -->
		
		</div>
		<!--comment Body-->
		
	</div><!-- #comment-##  -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'empo' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __('(Edit)', 'empo'), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}
endif;

/**
 * Register widgetized area and update sidebar with default widgets
 */
function empo_widgets_init() {
	register_sidebar( array (
		'name' => __( 'Top Panel', 'empo' ),
		'id' => 'sidebar-top',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array (
		'name' => __( 'Sidebar', 'empo' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	/* Register the 'first area' sidebar. */
	register_sidebar(
		array(
			'id' => 'first-footer-widget-area',
			'name' => __( 'First-Footer-Widget-Area','anariel'),
			'description' => __( 'The first footer widget area', 'anariel'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );
	/* Register the 'second area' sidebar. */
	register_sidebar(
		array(
			'id' => 'second-footer-widget-area',
			'name' => __( 'Second-Footer-Widget-Area','anariel'),
			'description' => __( 'The second footer widget area', 'anariel'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );
}
add_action( 'init', 'empo_widgets_init' );

/**
 * Removes the default styles that are packaged with the Recent Comments widget.
 */
function empo_remove_recent_comments_style() {
	global $wp_widget_factory;
	remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );
}
add_action( 'widgets_init', 'empo_remove_recent_comments_style' );

/**
 * Search form custom styling
 */
function empo_search_form( $form ) {

    $form = '<form role="search" method="get" class="searchform" action="'.get_bloginfo('url').'" >
    <div><label class="screen-reader-text" for="s">' . __('Search', 'empo') . '</label>
    <input type="text" class="search-input" value="' . get_search_query() . '" name="s" id="s" />
    <input type="submit" class="searchsubmit" value="'. esc_attr__('Search', 'empo') .'" />
    </div>
    </form>';

    return $form;
}
add_filter( 'get_search_form', 'empo_search_form' );

/**
 * Remove the default CSS style from the WP image gallery
 */
add_filter('gallery_style', create_function('$a', 'return "
<div class=\'gallery\'>";'));
/*-----------------------------------------------------------------------------------*/
/*	Adds the Customize page to the WordPress admin area
/*-----------------------------------------------------------------------------------*/ 
function empo_customizer_menu() {
    add_theme_page( __('Customize','anariel'), __('Customize','anariel'), 'edit_theme_options', 'customize.php' );
}
add_action( 'admin_menu', 'empo_customizer_menu' );
/**
 * Adds the individual sections for custom logo
 */
 function empo_theme_customizer( $wp_customize ) {
   $wp_customize->add_section( 'empo_logo_section' , array(
    'title'       => __( 'Logo', 'empo' ),
    'priority'    => 30,
    'description' => 'Upload a logo to replace the default site name and description in the header',
) );
$wp_customize->add_setting( 'empo_logo' );
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'empo_logo', array(
    'label'    => __( 'Logo', 'empo' ),
    'section'  => 'empo_logo_section',
    'settings' => 'empo_logo',
) ) );
}
add_action('customize_register', 'empo_theme_customizer');
function Ari_customize_register( $wp_customize ) {
	$colors = array();
$colors[] = array(
	'slug'=>'content_link_color', 
	'default' => '#00b5c0',
	'label' => __('Change links and borders blue color', 'Ari')
);
foreach( $colors as $color ) {
	// SETTINGS
	$wp_customize->add_setting(
		$color['slug'], array(
			'default' => $color['default'],
			'type' => 'option', 
			'capability' => 
			'edit_theme_options'
		)
	);
	// CONTROLS
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			$color['slug'], 
			array('label' => $color['label'], 
			'section' => 'colors',
			'settings' => $color['slug'])
		)
	);
}
}
add_action( 'customize_register', 'Ari_customize_register' );
?>